==> iTop-3.2.0-2-14758.zip: web/datamodels/2.x/itop-faq-light/dictionaries/nl.dict.itop-faq-light.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 * @author LinProfs <info@linprofs.com>
 * @author Jeffrey Bostoen <info@jeffreybostoen.be> (2018 - 2022)
 *
 */
Dict::Add('NL NL', 'Dutch', 'Nederlands', [
	'Brick:Portal:FAQ:Menu' => 'FAQ',
	'Brick:Portal:FAQ:Title' => 'Veelgestelde vragen',
	'Brick:Portal:FAQ:Title+' => '<p>Gehaast?</p><p>Bekijk deze lijst van veelgestelde vragen. Misschien staat er al een antwoord tussen.</p>',
	'Class:FAQ' => 'FAQ',
	'Class:FAQ+' => 'Veelgestelde vragen',
	'Class:FAQ/Attribute:category_id' => 'Categorie',
	'Class:FAQ/Attribute:category_id+' => '',
	'Class:FAQ/Attribute:category_name' => 'Naam categorie',
	'Class:FAQ/Attribute:category_name+' => '',
	'Class:FAQ/Attribute:description' => 'Omschrijving',
	'Class:FAQ/Attribute:description+' => '',
	'Class:FAQ/Attribute:domains' => 'Domeinen',
	'Class:FAQ/Attribute:error_code' => 'Foutcode',
	'Class:FAQ/Attribute:error_code+' => '',
	'Class:FAQ/Attribute:key_words' => 'Zoektermen',
	'Class:FAQ/Attribute:key_words+' => '',
	'Class:FAQ/Attribute:summary' => 'Samenvatting',
	'Class:FAQ/Attribute:summary+' => '',
	'Class:FAQ/Attribute:title' => 'Titel',
	'Class:FAQ/Attribute:title+' => '',
	'Class:FAQCategory' => 'FAQ-categorie',
	'Class:FAQCategory+' => 'Categorie voor de FAQ',
	'Class:FAQCategory/Attribute:faq_list' => 'FAQ\'s',
	'Class:FAQCategory/Attribute:faq_list+' => 'Alle veelgestelde vragen gerelateerd aan deze categorie',
	'Class:FAQCategory/Attribute:name' => 'Naam',
	'Class:FAQCategory/Attribute:name+' => '',
	'Menu:FAQ' => 'FAQ\'s',
	'Menu:FAQ+' => 'Alle FAQ\'s',
	'Menu:FAQCategory' => 'FAQ-categorieën',
	'Menu:FAQCategory+' => 'Alle FAQ-categorieën',
	'Menu:Problem:Shortcuts' => 'Snelkoppelingen',
	'Menu:ProblemManagement' => 'Probleem Management',
	'Menu:ProblemManagement+' => 'Probleem Management',
]);

==> iTop-3.2.2-1-17851.zip: web/datamodels/2.x/itop-faq-light/dictionaries/nl.dict.itop-faq-light.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 * @author LinProfs <info@linprofs.com>
 * @author Jeffrey Bostoen <info@jeffreybostoen.be> (2018 - 2022)
 *
 */
Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Class:FAQ' => 'FAQ',
	'Class:FAQ+' => 'Veelgestelde vragen',
	'Class:FAQ/Attribute:title' => 'Titel',
	'Class:FAQ/Attribute:title+' => '',
	'Class:FAQ/Attribute:summary' => 'Samenvatting',
	'Class:FAQ/Attribute:summary+' => '',
	'Class:FAQ/Attribute:description' => 'Omschrijving',
	'Class:FAQ/Attribute:description+' => '',
	'Class:FAQ/Attribute:category_id' => 'Categorie',
	'Class:FAQ/Attribute:category_id+' => '',
	'Class:FAQ/Attribute:category_name' => 'Naam categorie',
	'Class:FAQ/Attribute:category_name+' => '',
	'Class:FAQ/Attribute:error_code' => 'Foutcode',
	'Class:FAQ/Attribute:error_code+' => '',
	'Class:FAQ/Attribute:key_words' => 'Zoektermen',
	'Class:FAQ/Attribute:key_words+' => '',
	'Class:FAQ/Attribute:domains' => 'Domeinen',
));

//
// Class: FAQCategory
//

Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Class:FAQCategory' => 'FAQ-categorie',
	'Class:FAQCategory+' => 'Categorie voor de FAQ',
	'Class:FAQCategory/Attribute:name' => 'Naam',
	'Class:FAQCategory/Attribute:name+' => '',
	'Class:FAQCategory/Attribute:faq_list' => 'FAQ\'s',
	'Class:FAQCategory/Attribute:faq_list+' => 'Alle veelgestelde vragen gerelateerd aan deze categorie',
));
Dict::Add('NL NL', 'Dutch', 'Nederlands', array(
	'Menu:ProblemManagement' => 'Probleem Management',
	'Menu:ProblemManagement+' => 'Probleem Management',
	'Menu:Problem:Shortcuts' => 'Snelkoppelingen',
	'Menu:FAQCategory' => 'FAQ-categorieën',
	'Menu:FAQCategory+' => 'Alle FAQ-categorieën',
	'Menu:FAQ' => 'FAQ\'s',
	'Menu:FAQ+' => 'Alle FAQ\'s',
	'Brick:Portal:FAQ:Menu' => 'FAQ',
	'Brick:Portal:FAQ:Title' => 'Veelgestelde vragen',
	'Brick:Portal:FAQ:Title+' => '<p>Gehaast?</p><p>Bekijk deze lijst van veelgestelde vragen. Misschien staat er al een antwoord tussen.</p>',
));
